=========
Changelog
=========

Version 0.0.5
=============

- Fix date and datetime conversion for numpy scalars

Version 0.0.4
=============

- Add days2dt and dt2days conversion function

Version 0.0.3
=============

- Fix numpy warning

Version 0.0.2
=============

- Add dekad module (from pytesmo)

Version 0.0.1
=============

- Initial package draft
